==> haskell-aws-0.16-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.16
id: aws-0.16-I8eYjkkNPQeJkejMzAObvi
key: aws-0.16-I8eYjkkNPQeJkejMzAObvi
license: BSD3
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
author: Aristid Breitkreuz, contributors see README
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.PutBucket Aws.S3.Commands.PutObject
    Aws.S3.Commands.Multipart Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
abi: 67e433cf930753cbb699c61d43b39937
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aws-0.16
library-dirs: /usr/lib/ghc-8.0.1/site-local/aws-0.16
data-dir: /usr/share/i386-linux-ghc-8.0.1/aws-0.16
hs-libraries: HSaws-0.16-I8eYjkkNPQeJkejMzAObvi
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    case-insensitive-1.2.0.8-6RHKQz6dPK3ENaPtabAPQ
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-9BEhw2PHvUTFj1lUJfHKAK containers-0.5.7.1
    cryptohash-0.11.9-7DFTpGt1NsYGD2GaWWablc
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    filepath-1.4.1.0 http-conduit-2.2.3.1-3LyhPeOXlC71EIY0PtL1cb
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    xml-conduit-1.4.0.4-C5gqbUtQ6Lb8x9eYy50Usu
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.16-22-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.16
id: aws-0.16-8hw3mZIlEobFhqmSbViMrQ
key: aws-0.16-8hw3mZIlEobFhqmSbViMrQ
license: BSD3
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
author: Aristid Breitkreuz, contributors see README
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.PutBucket Aws.S3.Commands.PutObject
    Aws.S3.Commands.Multipart Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
abi: 5f84e28c5b6e4f546bb2c89ef59836e8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aws-0.16
library-dirs: /usr/lib/ghc-8.0.1/site-local/aws-0.16
data-dir: /usr/share/i386-linux-ghc-8.0.1/aws-0.16
hs-libraries: HSaws-0.16-8hw3mZIlEobFhqmSbViMrQ
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi
    conduit-1.2.9.1-GZZC8SxHl2s2gE2ucPFZOM
    conduit-extra-1.1.15-7KQDtEJYa8uHngwwxCyMqo containers-0.5.7.1
    cryptohash-0.11.9-E1hIynbSeej7VAW0TGWaxE
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    filepath-1.4.1.0 http-conduit-2.2.3.1-BCLt1BnpYRmFMDLZQjVgHH
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    xml-conduit-1.4.0.4-8B3uqSAzjMk1rnNqTAOhm0
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
